Module path

Module path 

Helpers for editing animated paths at the correct frame.

Functions

path_edit_target
Determine whether path edits should target the static base path or a keyframe at playhead, and whether a seed keyframe must be created first.